@@ -4,4 +4,4 @@ from django_countries import CountryField
 
 class Person(models.Model):
     name = models.CharField(max_length=50)
-    country = CountryField()
+    country = CountryField(blank=True)
